==> open-xchange-soap-cxf_6.18.0.0.orig.tar.gz: open-xchange-soap-cxf-6.18.0.0/src/com/openexchange/soap/cxf/osgi/CXFActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.soap.cxf.osgi;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.transport.servlet.CXFNonSpringServlet;
import org.osgi.service.http.HttpService;
import com.openexchange.server.osgiservice.DeferredActivator;
/**
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class CXFActivator extends DeferredActivator {
    private static final String PATH = "/webservices";
    private static final Log LOG = LogFactory.getLog(CXFActivator.class);
    
    
    private static final Class<?>[] CLASSES = new Class[]{HttpService.class};
    private WebserviceCollector collector;

    @Override
    protected Class<?>[] getNeededServices() {
        return CLASSES;
    }

    @Override
    protected void handleAvailability(Class<?> clazz) {
        
    }

    @Override
    protected void handleUnavailability(Class<?> clazz) {
        // TODO Auto-generated method stub
        
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            LOG.info("Starting Bundle :com.openexchange.soap.cxf");
            HttpService httpService = getService(HttpService.class);
            final CXFNonSpringServlet cxf = new CXFNonSpringServlet();
            final Bus bus = cxf.getBus();
            BusFactory.setDefaultBus(bus);

            LOG.info("Registering CXF servlet under "+PATH);
            httpService.registerServlet(PATH, cxf, null, null);

            collector = new WebserviceCollector(context);
            context.addServiceListener(collector);
            collector.open();
            LOG.info("com.openexchange.soap.cxf is up and running");
        } catch (Throwable t) {
            LOG.error(t.getMessage(), t);
        }
                
    }

    @Override
    protected void stopBundle() throws Exception {
        HttpService httpService = getService(HttpService.class);
        httpService.unregister(PATH);
        if (null != collector) {
            collector.close();
            collector = null;
        }
    }


}

==> open-xchange-soap-cxf_6.20.8.0.orig.tar.gz: open-xchange-soap-cxf-6.20.8.0/src/com/openexchange/soap/cxf/osgi/CXFActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.soap.cxf.osgi;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.cxf.Bus;
import org.apache.cxf.BusFactory;
import org.apache.cxf.transport.servlet.CXFNonSpringServlet;
import org.osgi.service.http.HttpService;
import com.openexchange.server.osgiservice.DeferredActivator;
/**
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class CXFActivator extends DeferredActivator {
    private static final String PATH = "/webservices";
    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(CXFActivator.class));
    
    
    private static final Class<?>[] CLASSES = new Class[]{HttpService.class};
    private WebserviceCollector collector;

    @Override
    protected Class<?>[] getNeededServices() {
        return CLASSES;
    }

    @Override
    protected void handleAvailability(Class<?> clazz) {
        
    }

    @Override
    protected void handleUnavailability(Class<?> clazz) {
        // TODO Auto-generated method stub
        
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            LOG.info("Starting Bundle :com.openexchange.soap.cxf");
            HttpService httpService = getService(HttpService.class);
            final CXFNonSpringServlet cxf = new CXFNonSpringServlet();
            final Bus bus = cxf.getBus();
            BusFactory.setDefaultBus(bus);

            LOG.info("Registering CXF servlet under "+PATH);
            httpService.registerServlet(PATH, cxf, null, null);

            collector = new WebserviceCollector(context);
            context.addServiceListener(collector);
            collector.open();
            LOG.info("com.openexchange.soap.cxf is up and running");
        } catch (Throwable t) {
            LOG.error(t.getMessage(), t);
        }
                
    }

    @Override
    protected void stopBundle() throws Exception {
        HttpService httpService = getService(HttpService.class);
        if (httpService != null) {
            httpService.unregister(PATH);
        }
        if (null != collector) {
            collector.close();
            collector = null;
        }
    }


}
